<?php

namespace Repositories;

use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\Util\QuerySelector;

class OAccTekMgr {
    /**
     * @param $nrOrg
     * @param $defaultOrgId
     * @return array
     */
    public function getOAccTekMgrByNrOrg($nrOrg, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $query = <<<SQL
                  SELECT RECURRENCE_DAYS AS "RECURRENCE_DAYS", NRORG AS "NRORG", OACCTEK_PHP7 AS "OACCTEK", TO_CHAR(DTULTATU, 'DD/MM/YYYY') AS "DTULTATU"
                    FROM OACCTEKMGR
                   WHERE NRORG = :NRORG
SQL;

        $params = array(
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }

    public function getDbHostInfo() {
        $connection = InstanceProvider::getEntityManager()->getConnection();
        //TODO ver como fazer
        $queryOracle = 'SELECT DBID || \'_\' || USER AS "DBINFO"
                    FROM V$DATABASE';

        $queryPostgre = <<<SQL
                  select '' AS "DBINFO"
SQL;
        $arrayQueries = array(
            'default' => $queryOracle,
            'pdo_pgsql' => $queryPostgre
        );
        $query = QuerySelector::getQueryByDriver($connection,$arrayQueries);

        $result = $connection->fetchAll($query);
        return !empty($result) ? $result[0]['DBINFO'] : '';
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @param $recurrenceDays
     * @param $oAccTek
     * @param $defaultOrgId
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function insertOAccTekMgr($nrOrg, $cdOperator , $recurrenceDays, $oAccTek, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $dateTimeFormat = 'DD/MM/YYYY HH24:MI:SS';
        $query = <<<SQL
                  INSERT INTO OACCTEKMGR
                              (NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, RECURRENCE_DAYS, OACCTEK_PHP7, OACCTEK)
                       VALUES (:NRORG, TO_DATE(:NOW,'$dateTimeFormat'), TO_DATE(:NOW,'$dateTimeFormat'), :NRORG, :CDOPERADOR, :RECURRENCE_DAYS, :OACCTEK, :OACCTEK)
SQL;

        $params = array(
            'NRORG'           => $nrOrg,
            'CDOPERADOR'      => $cdOperator,
            'RECURRENCE_DAYS' => $recurrenceDays,
            "NOW"     => Utilities::getCurrentDateTimeString(),
            'OACCTEK'         => $oAccTek
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @param $recurrenceDays
     * @param $oAccTek
     * @param $defaultOrgId
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function updateOAccTekMgr($nrOrg, $cdOperator , $recurrenceDays, $oAccTek, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $dateTimeFormat = 'DD/MM/YYYY HH24:MI:SS';
        $query = <<<SQL
                  UPDATE OACCTEKMGR
                     SET OACCTEK_PHP7 = :OACCTEK,
                         RECURRENCE_DAYS = :RECURRENCE_DAYS,
                         NRORGULTATU = :NRORG,
                         DTULTATU = TO_DATE(:DTULTATU,'$dateTimeFormat'),
                         CDOPERULTATU = :CDOPERADOR
                   WHERE NRORG = :NRORG
SQL;

        $params = array(
            'NRORG'           => $nrOrg,
            'CDOPERADOR'      => $cdOperator,
            'RECURRENCE_DAYS' => $recurrenceDays,
            'DTULTATU'        => Utilities::getCurrentDateTimeString(),
            'OACCTEK'         => $oAccTek
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }
}